@@ -37,12 +37,30 @@ public class AbstractBaseJavaEntity implements Serializable {
 	    this.lineNumber = lineNumber;
 	}
 
+	/**
+	 *  
+	 * @return
+	 * @deprecated
+	 */
 	public JavaClassParent getParent() { 
 	    return parent; 
 	}
 
+	/**
+	 * 
+	 * @param parent
+	 * @deprecated
+	 */
 	public void setParent(JavaClassParent parent) { 
 	    this.parent = parent;
 	}
+	
+	/**
+	 * Not every entity has a parentClass, but AnnotationFieldRef requires access to it.
+	 * When used with JavaClass, don't confuse this with getSuperClass()
+	 * 
+	 * @return the surrounding class
+	 */
+	public JavaClass getParentClass() { return null; }
 
 }
\ No newline at end of file
