@@ -2,13 +2,13 @@ package com.thoughtworks.qdox.model;
 
 /**
  * @author Aslak Helles&oslash;y
- * @version $Revision: 334 $
+ * @version $Revision: 546 $
  */
 public class DefaultDocletTagFactory implements DocletTagFactory {
 
     public DocletTag createDocletTag(
         String tag, String text, 
-        AbstractJavaEntity context, int lineNumber
+        AbstractBaseJavaEntity context, int lineNumber
     ) {
         return new DefaultDocletTag(tag, text, context, lineNumber);
     }
