@@ -4,7 +4,7 @@ import java.io.Serializable;
 
 /**
  * @author Aslak Helles&oslash;y
- * @version $Revision: 345 $
+ * @version $Revision: 546 $
  */
 public interface DocletTagFactory extends Serializable {
 
@@ -13,7 +13,7 @@ public interface DocletTagFactory extends Serializable {
      */ 
     DocletTag createDocletTag(
         String tag, String text, 
-        AbstractJavaEntity context, int lineNumber
+        AbstractBaseJavaEntity context, int lineNumber
     );
 
     DocletTag createDocletTag(String tag, String text);
