@@ -329,24 +329,24 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
     }
 
     private void addMethodsFromSuperclassAndInterfaces(Set signatures,
-                                                       List methodList, JavaClass clazz) {
-        JavaMethod[] methods = clazz.getMethods();
+                                                       List methodList, JavaClass callingClazz) {
+        JavaMethod[] methods = callingClazz.getMethods();
 
         addNewMethods(signatures, methodList, methods);
 
-        JavaClass superclass = clazz.getSuperJavaClass();
+        JavaClass superclass = callingClazz.getSuperJavaClass();
 
         // TODO workaround for a bug in getSuperJavaClass
-        if ((superclass != null) && (superclass != clazz)) {
-            addMethodsFromSuperclassAndInterfaces(signatures, methodList,
+        if ((superclass != null) && (superclass != callingClazz)) {
+            callingClazz.addMethodsFromSuperclassAndInterfaces(signatures, methodList,
                     superclass);
         }
 
-        JavaClass[] implementz = clazz.getImplementedInterfaces();
+        JavaClass[] implementz = callingClazz.getImplementedInterfaces();
 
         for (int i = 0; i < implementz.length; i++) {
             if (implementz[i] != null) {
-                addMethodsFromSuperclassAndInterfaces(signatures, methodList,
+                callingClazz.addMethodsFromSuperclassAndInterfaces(signatures, methodList,
                         implementz[i]);
             }
         }
@@ -361,7 +361,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
                 String signature = method.getDeclarationSignature(false);
 
                 if (!signatures.contains(signature)) {
-                    methodList.add(method);
+                    methodList.add( new JavaMethodDelegate( this, method ) );
                     signatures.add(signature);
                 }
             }
@@ -375,17 +375,29 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
      * @return the matching method or null if no match is found.
      */
     public JavaMethod getMethodBySignature(String name, Type[] parameterTypes) {
+        return getMethod( name, parameterTypes, false );
+    }
+
+    /**
+     * This should be the signature for getMethodBySignature
+     * 
+     * @param name
+     * @param parameterTypes
+     * @param varArgs
+     * @return
+     */
+    public JavaMethod getMethod(String name, Type[] parameterTypes, boolean varArgs) {
         JavaMethod[] methods = getMethods();
 
         for (int i = 0; i < methods.length; i++) {
-            if (methods[i].signatureMatches(name, parameterTypes, false)) {
+            if (methods[i].signatureMatches(name, parameterTypes, varArgs)) {
                 return methods[i];
             }
         }
 
         return null;
     }
-
+    
     /**
      * 
      * @param name
@@ -408,6 +420,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
      */
     public JavaMethod getMethodBySignature(String name, Type[] parameterTypes,
                                            boolean superclasses, boolean varArg) {
+        
         JavaMethod[] result = getMethodsBySignature(name, parameterTypes,
                 superclasses, varArg);
 
@@ -438,7 +451,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
                                               Type[] parameterTypes, boolean superclasses, boolean varArg) {
         List result = new ArrayList();
 
-        JavaMethod methodInThisClass = getMethodBySignature(name, parameterTypes);
+        JavaMethod methodInThisClass = getMethod(name, parameterTypes, varArg);
 
         if (methodInThisClass != null) {
             result.add(methodInThisClass);
@@ -453,7 +466,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
 
                 // todo: ideally we should check on package privacy too. oh well.
                 if ((method != null) && !method.isPrivate()) {
-                    result.add(method);
+                    result.add( new JavaMethodDelegate( this, method ) );
                 }
             }
 
@@ -464,7 +477,7 @@ public class JavaClass extends AbstractInheritableJavaEntity implements JavaClas
                         parameterTypes, true, varArg );
 
                 if (method != null) {
-                    result.add(method);
+                    result.add( new JavaMethodDelegate( this, method ) );
                 }
             }
         }
